EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Configuration_GetOrAddValue',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Value_Text',
    /* Description_Text        */ 'Sets a InedoSecurityLabs configuration value if it does not yet exist, otherwise returns the original value.'
GO

IF OBJECT_ID('[Configuration_GetOrAddValue]') IS NOT NULL DROP PROCEDURE [Configuration_GetOrAddValue]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Configuration_GetOrAddValue]
(
	@Key_Name VARCHAR(200),
	@Value_Text NVARCHAR(MAX) OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @CurrentValue_Text NVARCHAR(MAX)
	SET @CurrentValue_Text = (SELECT [Value_Text]
	                            FROM [Configuration]
								WITH (UPDLOCK)
							   WHERE [Key_Name] = @Key_Name)

	IF @CurrentValue_Text IS NULL
		INSERT INTO [Configuration]
		(
			[Key_Name],
			[Value_Text]
		)
		VALUES
		(
			@Key_Name,
			@Value_Text
		)
	ELSE
		SET @Value_Text = @CurrentValue_Text

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	--EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Configuration_GetOrAddValue] TO [InedoSecurityLabsUser_Role]
GO
