EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Configuration_SetValue',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Sets a InedoSecurityLabs configuration value.'
GO


IF OBJECT_ID('[Configuration_SetValue]') IS NOT NULL DROP PROCEDURE [Configuration_SetValue]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Configuration_SetValue]
(
	@Key_Name VARCHAR(200),
	@Value_Text NVARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Value_Text IS NULL BEGIN

		DELETE [Configuration]
		 WHERE [Key_Name] = @Key_Name

	END ELSE BEGIN

		DECLARE @CurrentValue_Text NVARCHAR(MAX)
		SET @CurrentValue_Text = (SELECT [Value_Text]
		                            FROM [Configuration]
									WITH (UPDLOCK)
								   WHERE [Key_Name] = @Key_Name)
	
		IF @CurrentValue_Text IS NULL
		BEGIN
	
			INSERT INTO [Configuration]
			(
				[Key_Name],
				[Value_Text]
			)
			VALUES
			(
				@Key_Name,
				@Value_Text
			)
	
			--IF dbo.Session_GetUserName() NOT IN ('UNKNOWN', 'SYSTEM')
				--EXEC [Events_RaiseEvent] 'SYSCFG', NULL, 'Key_Name', @Key_Name
	
		END
		ELSE IF CAST(@CurrentValue_Text AS VARBINARY(MAX)) <> CAST(@Value_Text AS VARBINARY(MAX))
		BEGIN
	
			UPDATE [Configuration]
			   SET [Value_Text] = @Value_Text
			 WHERE [Key_Name] = @Key_Name
	
			--IF dbo.Session_GetUserName() NOT IN ('UNKNOWN', 'SYSTEM')
				--EXEC [Events_RaiseEvent] 'SYSCFG', NULL, 'Key_Name', @Key_Name
	
		END

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	--EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Configuration_SetValue] TO [InedoSecurityLabsUser_Role]
GO
