EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_AddLogEntry',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a log entry.'
GO

IF OBJECT_ID('[Executions_AddLogEntry]') IS NOT NULL DROP PROCEDURE [Executions_AddLogEntry]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_AddLogEntry]
(
	@Execution_Id INT,
	@Scope_Sequence INT,
	@LogEntry_Level INT,
	@LogEntry_Text VARCHAR(MAX),
	@LogEntry_Date DATETIME,
	@LogEntry_Sequence INT = NULL
)
AS
BEGIN

SET NOCOUNT ON

IF @LogEntry_Sequence IS NULL
	WITH A AS(
		SELECT [Next_Sequence] = COALESCE(MAX([LogEntry_Sequence]), 0) + 1
	      FROM [ScopedExecutionLogEntries]
	     WHERE [Execution_Id] = @Execution_Id
	)
	INSERT INTO [ScopedExecutionLogEntries]
	(
		[Execution_Id],
		[Scope_Sequence],
		[LogEntry_Sequence],
		[LogEntry_Level],
		[LogEntry_Text],
		[LogEntry_Date]
	)
	SELECT @Execution_Id,
	       @Scope_Sequence,
		   A.[Next_Sequence],
		   @LogEntry_Level,
		   @LogEntry_Text,
		   @LogEntry_Date
	 FROM A
ELSE
	INSERT INTO [ScopedExecutionLogEntries]
	(
		[Execution_Id],
		[Scope_Sequence],
		[LogEntry_Sequence],
		[LogEntry_Level],
		[LogEntry_Text],
		[LogEntry_Date]
	)
	VALUES
	(
		@Execution_Id,
		@Scope_Sequence,
		@LogEntry_Sequence,
		@LogEntry_Level,
		@LogEntry_Text,
		@LogEntry_Date
	)

END
GO

GRANT EXECUTE ON [Executions_AddLogEntry] TO [InedoSecurityLabsUser_Role]
