EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_FailExecutions',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ NULL,
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Marks all incomplete executions as failed.'
GO

IF OBJECT_ID('[Executions_FailExecutions]') IS NOT NULL DROP PROCEDURE [Executions_FailExecutions]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_FailExecutions]
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Executions TABLE ([Execution_Id] INT NOT NULL)

	INSERT INTO @Executions
	SELECT [Execution_Id]
	  FROM [Executions] WHERE [ExecutionRunState_Code] <> 'C'

	-- Fail unfinished executions	
	UPDATE [Executions]
	   SET [ExecutionRunState_Code] = 'C',
	       [ExecutionStatus_Code] = 'E',
		   [End_Date] = GETUTCDATE()
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	-- set highest log entry and end date for scoped logs that never completed
	UPDATE [ScopedExecutionLogs]
	   SET [End_Date] = GETUTCDATE(),
	       [HighestLogEntry_Level] = (SELECT MAX([LogEntry_Level])
		                                FROM [ScopedExecutionLogEntries] LE
								       WHERE LE.[Execution_Id] = L.[Execution_Id]
								         AND LE.[Scope_Sequence] = L.[Scope_Sequence])
      FROM [ScopedExecutionLogs] L
     WHERE L.[Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)
	   AND [End_Date] IS NULL

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH		 

END
GO

GRANT EXECUTE ON [Executions_FailExecutions] TO [InedoSecurityLabsUser_Role]