EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Vulnerabilities_GetAllVulnerabilitites',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataSet',
    /* DataTableNames_Csv      */ 'Vulnerabilities_Extended,VulnerabilityPackages',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Retrieves all vulnerabilties.'
GO

IF OBJECT_ID('[Vulnerabilities_GetAllVulnerabilitites]') IS NOT NULL DROP PROCEDURE [Vulnerabilities_GetAllVulnerabilitites]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Vulnerabilities_GetAllVulnerabilitites]
(
    @IncludeWithdrawn_Indicator YNINDICATOR = 'N'
)
AS
BEGIN
    SET NOCOUNT ON

    DECLARE @VulnerabilityIds TABLE ([Vulnerability_Id] INT);

    WITH FilteredVulnerabilites AS  
    (
        SELECT V.*, [ROW_NUMBER] = ROW_NUMBER() OVER (ORDER BY COALESCE(V.[Published_Date], V.[Modified_Date]) DESC)
        FROM [Vulnerabilities_Extended] V
        WHERE @IncludeWithdrawn_Indicator = 'Y' OR ((@IncludeWithdrawn_Indicator = 'N' OR @IncludeWithdrawn_Indicator IS NULL) AND V.[Withdrawn_Date] IS NULL)
    )
    INSERT INTO @VulnerabilityIds
    SELECT [Vulnerability_Id] 
    FROM FilteredVulnerabilites
  

    SELECT * 
    FROM [Vulnerabilities_Extended] V
    WHERE V.[Vulnerability_Id] IN (
        SELECT [Vulnerability_Id] FROM @VulnerabilityIds
    )
    ORDER BY V.[Modified_Date] DESC

    SELECT * 
    FROM [VulnerabilityPackages] VP
    WHERE VP.[Vulnerability_Id] IN (
        SELECT [Vulnerability_Id] FROM @VulnerabilityIds
    )

END
GO

GRANT EXECUTE ON [Vulnerabilities_GetAllVulnerabilitites] TO [InedoSecurityLabsUser_Role]
GO