EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Vulnerabilities_GetVulnerabilitites',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataSet',
    /* DataTableNames_Csv      */ 'Vulnerabilities_Extended,VulnerabilityPackages',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Searches for vulnerabilties.'
GO

IF OBJECT_ID('[Vulnerabilities_GetLatestVulnerabilitites]') IS NOT NULL DROP PROCEDURE [Vulnerabilities_GetLatestVulnerabilitites]
GO
IF OBJECT_ID('[Vulnerabilities_GetVulnerabilitites]') IS NOT NULL DROP PROCEDURE [Vulnerabilities_GetVulnerabilitites]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Vulnerabilities_GetVulnerabilitites]
(
    @Search_Text VARCHAR(255) = NULL,
    @Ecosystem_CSV VARCHAR(MAX) = NULL,
    @IncludeWithdrawn_Indicator YNINDICATOR = 'Y',
    @IncludeMaliciousPackages_Indicator YNINDICATOR = 'Y',
    @ShowOnlyInedoAnalysis_Indicator YNINDICATOR = NULL,
    @IncludeNoScore_Indicator YNINDICATOR = 'Y',
    @Skip_Count INT = NULL,
    @Take_Count INT = NULL
)
AS
BEGIN
    SET NOCOUNT ON
    SET @Skip_Count = COALESCE(@Skip_Count, 0)
    SET @Take_Count = COALESCE(@Take_Count, 50)

    DECLARE @VulnerabilityIds TABLE ([Vulnerability_Id] INT);

    DECLARE @Ecosystems TABLE ([Ecosystem_Name] VARCHAR(50));
    IF @Ecosystem_CSV IS NULL
    BEGIN
        INSERT INTO @Ecosystems
        SELECT DISTINCT V.[Ecosystem_Name]
        FROM [Vulnerabilities] V
    END
    ELSE
    BEGIN
        INSERT INTO @Ecosystems
        SELECT *
        FROM STRING_SPLIT(@Ecosystem_CSV, ',')
    END;

    WITH FilteredVulnerabilites AS  
    (
        SELECT V.*, [ROW_NUMBER] = ROW_NUMBER() OVER (ORDER BY COALESCE(V.[Published_Date], V.[Modified_Date]) DESC, V.[UniqueId_Text] DESC)
        FROM [Vulnerabilities_Extended] V
        INNER JOIN @Ecosystems E ON E.[Ecosystem_Name] = V.[Ecosystem_Name]
        WHERE
            (
                @Search_Text IS NULL
                OR 
                ( 
                    @Search_Text IS NOT NULL
                    AND (
                        V.[UniqueId_Text] LIKE '%' + @Search_Text + '%' 
                        OR V.[External_Id] LIKE '%' + @Search_Text + '%')
                        OR V.[Vulnerability_Id] IN (
                            SELECT VP.[Vulnerability_Id]
                            FROM [VulnerabilityPackages] VP
                            WHERE (VP.[PUrl_Text] LIKE 'pkg:%/%' + @Search_Text + '%')
                    )
                )
            )
            AND (@IncludeWithdrawn_Indicator IS NULL OR @IncludeWithdrawn_Indicator = 'Y' OR (@IncludeWithdrawn_Indicator = 'N' AND V.[Withdrawn_Date] IS NULL))
            AND (@IncludeMaliciousPackages_Indicator IS NULL OR @IncludeMaliciousPackages_Indicator = 'Y' OR (@IncludeMaliciousPackages_Indicator = 'N' AND V.[External_Id] NOT LIKE 'MAL-%'))
            AND (@IncludeNoScore_Indicator IS NULL OR @IncludeNoScore_Indicator = 'Y' OR (@IncludeNoScore_Indicator = 'N' AND V.[CVSSScore_Text] IS NOT NULL))
            AND (@ShowOnlyInedoAnalysis_Indicator IS NULL OR (@ShowOnlyInedoAnalysis_Indicator = 'N' AND V.[HasAnalysis_Indicator] = 'N') OR (@ShowOnlyInedoAnalysis_Indicator = 'Y' AND V.[HasAnalysis_Indicator] = 'Y'))
    )
    INSERT INTO @VulnerabilityIds
    SELECT [Vulnerability_Id] 
    FROM FilteredVulnerabilites
    WHERE [Row_Number] BETWEEN @Skip_Count AND @Skip_Count + @Take_Count    

    SELECT * 
    FROM [Vulnerabilities_Extended] V
    WHERE V.[Vulnerability_Id] IN (
        SELECT [Vulnerability_Id] FROM @VulnerabilityIds
    )
    ORDER BY COALESCE(V.[Published_Date], V.[Modified_Date]) DESC, V.[UniqueId_Text] DESC

    SELECT * 
    FROM [VulnerabilityPackages] VP
    WHERE VP.[Vulnerability_Id] IN (
        SELECT [Vulnerability_Id] FROM @VulnerabilityIds
    )

END
GO

GRANT EXECUTE ON [Vulnerabilities_GetVulnerabilitites] TO [InedoSecurityLabsUser_Role]
GO